@@ -160,7 +160,7 @@ void CalendarComponentListWidget::renderNote(){
     QDateTime qdtDateStamp;
     qdtDateStamp.setTime_t(journal->getLastModified());
     //QString summary(journal->getSummary().c_str());
-    w->setSummary(QString::fromLocal8Bit(journal->getSummary().c_str()));//  summary.simplified());
+    w->setSummary((QString::fromLocal8Bit(journal->getSummary().c_str())).simplified());
     w->setUpdatedDate(qdtDateStamp);
 
     delete calendar;
