@@ -2,6 +2,7 @@
 #define DB_H
 #include "folder.h"
 #include <calendar-backend/CCalendar.h>
+
 class DB
 {
 public:
@@ -12,6 +13,9 @@ public:
     static bool checkFolderExists(QString FolderName, int ParentLevel);
     static bool createNewFolder(QString FolderName, int ParentLevel);
     static QString getFolderName(int FolderId);
+    static CCalendar* getDefaultCalendar();
+    static int getMinimumCalendarId();
+    static void unlinkFolder(int FolderId);
 };
 
 #endif // DB_H
