@@ -3,6 +3,7 @@
 #include <QMessageBox>
 #include <QMaemo5InformationBox>
 #include <QSqlQuery>
+#include "db.h"
 
 DialogDeleteFolder::DialogDeleteFolder(QWidget *parent) :
     QDialog(parent),
@@ -48,16 +49,8 @@ bool DialogDeleteFolder::getDeleted(){
 }
 
 void DialogDeleteFolder::unlinkFolder(){
+
     if(this->folderId < 1) return;
-
-    QSqlQuery q1;
-    q1.prepare("DELETE FROM FolderItem WHERE FolderId = ?");
-    q1.addBindValue(this->folderId);
-    q1.exec();
-
-    QSqlQuery q2;
-    q2.prepare("DELETE FROM Folder WHERE FolderId = ?");
-    q2.addBindValue(this->folderId);
-    q2.exec();
+    DB::unlinkFolder(this->folderId);
 
 }
