@@ -18,6 +18,9 @@ class FormHome : public QWidget
 public:
     explicit FormHome(QWidget *parent = 0);
     ~FormHome();
+
+public slots:
+
     
 private slots:
     void on_listWidgetHome_activated(const QModelIndex &index);
@@ -28,6 +31,8 @@ private slots:
 
     void on_pushButton_clicked();
 
+    void updateQueries();
+
 private:
     Ui::FormHome *ui;
     QSqlQueryModel *group_model;
@@ -41,7 +46,7 @@ private:
     void launchTomorrow();
     void launchTasks();
     void launchNotes();
-
+    void getNav();
 
 };
 
